@@ -73,7 +73,7 @@ USA.
 #include "_slang.h"
 
 int SLang_TT_Read_FD = -1;
-int SLang_TT_Baud_Rate;
+int SLang_TT_Baud_Rate = 0;
 
 #ifdef HAVE_TERMIOS_H
 # if !defined(HAVE_TCGETATTR) || !defined(HAVE_TCSETATTR)
@@ -518,7 +518,7 @@ int _pSLsys_input_pending(int tsecs)
    return select(SLang_TT_Read_FD + 1, &Read_FD_Set, NULL, NULL, &wait);
 }
 
-int (*SLang_getkey_intr_hook) (void);
+int (*SLang_getkey_intr_hook) (void) = NULL;
 
 static int handle_interrupt (void)
 {
